measuretools.Measure
====================

.. abjad-lineage:: abjad.tools.measuretools.Measure.Measure.Measure

.. autoclass:: abjad.tools.measuretools.Measure.Measure.Measure
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.descendants
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.has_non_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.has_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_full
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_misfilled
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_overfull
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_underfull
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.leaves
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.lineage
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.measure_number
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.music
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.override
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.parent
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.parentage
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.prolation
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.set
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.spanners
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.start_offset
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.storage_format
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.target_duration
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.timespan
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.always_format_time_signature
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.automatically_adjust_time_signature
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_parallel
   :noindex:

Methods
-------

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.append
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.extend
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.index
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.insert
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.pop
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__add__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__contains__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__delitem__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__eq__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__ge__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__getitem__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__gt__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__iadd__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__imul__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__le__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__len__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__lt__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__mul__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__ne__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__radd__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__repr__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__rmul__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__setitem__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__str__
   :noindex:
